@@ -139,12 +139,13 @@ class dyn_obj:
 
         int_curveOB.data.bevel_factor_start = 0
 
+        bpy.ops.object.convert(target='MESH')
+
         if staticity == 'dynamic':
-            for i in range(len(frames)):
-                cur_frame = frames[i]
-                
-                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]) * cur_frame
-                bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
+            bpy.ops.object.modifier_add(type='BUILD')
+            bpy.context.object.modifiers["Build"].frame_start = 0
+            bpy.context.object.modifiers["Build"].frame_duration = self.frames[-1]
+
 
 class dyn_vec:
     def __init__(self, obj, name, scale_mag, scale_off, offset, anim):
@@ -223,25 +224,17 @@ class anim_text:
         self.obj.parent = parent
         self.name = name
 
+        all_frames = np.arange(1, anim.frames[-1])
+        frame_interper = interp1d(anim.frames, data, fill_value = 'extrapolate')
+
+        fixed_data = frame_interper(all_frames)
 
         if not(if_str):
-            all_frames = np.arange(1, anim.frames[-1])
-            frame_interper = interp1d(anim.frames, data, fill_value = 'extrapolate')
-
-            fixed_data = frame_interper(all_frames)
-
             def recalculate_text(scene):
                 text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
                 text.data.body = ('{0:.'+str(fix_place)+'f}').format(fixed_data[cur_frame-1]) + ' ' + label
-
-        else:
-            def recalculate_text(scene):
-                text = ob
-                cur_frame = bpy.context.scene.frame_current
-                
-                text.data.body = data + ' ' + label
                     
 
             bpy.app.handlers.frame_change_pre.append(recalculate_text)
